.. -*- coding: utf-8 -*-
.. :Progetto:  SoL
.. :Creato:    gio 06 nov 2008 14:47:43 CET
.. :Autore:    Lele Gaifax <lele@metapensiero.it>
.. :Licenza:   GNU General Public License version 3 or later
..

================
 User interface
================

I tried to keep the user interaction as simple as possible, focused on the typical *workflow*
of managing a new tourney: given a :ref:`club <clubs management>`, selected the
:ref:`championship <championships management>`, create a new :ref:`tourney <tourneys
management>` and then

1. insert the participants, selecting among known :ref:`players <players management>`, possibly
   organizing them in teams

   .. index:: Phantom

   .. note:: When the number of participants is *odd*, SoL **automatically** handle the
             presence of a `phantom player`, against whom any player wins with a score of
             **25—0** (for this reason the scoreboards for these imaginary matches are not even
             emitted). In particular cases the actual score assigned to the player may be
             changed on the :ref:`tourney insert and edit` window.

2. eventually print the initial individual :ref:`badges`

3. create the first turn: if the tourney is associated with a particular :ref:`glicko rating
   <glicko rating management>` it will be generated using the current rate of each player,
   otherwise using a random order; in any case, the tourney manager may manually adjust the
   combinations generated by the computer

4. print the :ref:`scoreboards` of the turn

5. let's play carrom!

6. collect compiled :ref:`scoreboards` and insert the resulting scores

7. compute the new ranking and eventually print it

8. verify what picky guys are telling and eventually correct and repeat

9. if desired, permit other people to join in, adding new participants, or some other to leave

10. compute the next turn and jump to point 4 until satisfied, or until all possible
    combinations are exausted, which ever comes first

11. assign the final prizes, print the ranking and the final :ref:`badges`

.. toctree::
   :maxdepth: 2

   authentication
   entities
   other
